FindBracketedMinimum

Trait FindBracketedMinimum 

pub trait FindBracketedMinimum<F>
where F: Callback,
{ // Required method fn find_minimum_in_bracket( &self, f: F, bracket: (f64, f64), ) -> Result<f64, RootFinderError>; }
Finds the minimum of a function within a bracket.

Required Methods

fn find_minimum_in_bracket( &self, f: F, bracket: (f64, f64), ) -> Result<f64, RootFinderError>

Finds the x value that minimizes f within the given bracket.

Implementors