FindBracketedRoot

Trait FindBracketedRoot 

pub trait FindBracketedRoot<F>
where F: Callback,
{ // Required method fn find_in_bracket( &self, f: F, bracket: (f64, f64), ) -> Result<f64, RootFinderError>; }
Finds a root of f within a bracket (a, b).

Required Methods

fn find_in_bracket( &self, f: F, bracket: (f64, f64), ) -> Result<f64, RootFinderError>

Finds a root of f within the given bracket.

Implementors

Source

impl<F> FindBracketedRoot<F> for Brent
where F: Callback,

Source

impl<F> FindBracketedRoot<F> for Secant
where F: Callback,