FindRootWithDerivative

Trait FindRootWithDerivative 

pub trait FindRootWithDerivative<F, D>
where F: Callback, D: Callback,
{ // Required method fn find_with_derivative( &self, f: F, derivative: D, initial_guess: f64, ) -> Result<f64, RootFinderError>; }
Finds a root of f using both the function and its derivative.

Required Methods

fn find_with_derivative( &self, f: F, derivative: D, initial_guess: f64, ) -> Result<f64, RootFinderError>

Finds a root of f using derivative, starting from initial_guess.

Implementors

Source

impl<F, D> FindRootWithDerivative<F, D> for Newton
where F: Callback, D: Callback,