pub struct Series { /* private fields */ }Expand description
An interpolated 1-D data series.
Implementations
Sourceimpl Series
impl Series
Sourcepub fn try_new(
x: impl Into<Arc<[f64]>>,
y: impl Into<Arc<[f64]>>,
interpolation: InterpolationType,
) -> Result<Series, SeriesError>
pub fn try_new( x: impl Into<Arc<[f64]>>, y: impl Into<Arc<[f64]>>, interpolation: InterpolationType, ) -> Result<Series, SeriesError>
Creates a new series, returning an error if the data is invalid.
Sourcepub fn new(
x: impl Into<Arc<[f64]>>,
y: impl Into<Arc<[f64]>>,
interpolation: InterpolationType,
) -> Series
pub fn new( x: impl Into<Arc<[f64]>>, y: impl Into<Arc<[f64]>>, interpolation: InterpolationType, ) -> Series
Creates a new series, panicking if the data is invalid.
Sourcepub fn find_index(&self, xp: f64) -> usize
pub fn find_index(&self, xp: f64) -> usize
Finds the interval index for interpolation at point xp.
Sourcepub fn interpolate_at_index(&self, xp: f64, idx: usize) -> f64
pub fn interpolate_at_index(&self, xp: f64, idx: usize) -> f64
Interpolates at point xp using the precomputed interval idx.
Sourcepub fn interpolate(&self, xp: f64) -> f64
pub fn interpolate(&self, xp: f64) -> f64
Interpolates the series at point xp.