pub trait FindBracketedRoot<F>where
F: Callback,{
// Required method
fn find_in_bracket(
&self,
f: F,
bracket: (f64, f64),
) -> Result<f64, RootFinderError>;
}Expand description
Finds a root of f within a bracket (a, b).
Required Methods
Sourcefn find_in_bracket(
&self,
f: F,
bracket: (f64, f64),
) -> Result<f64, RootFinderError>
fn find_in_bracket( &self, f: F, bracket: (f64, f64), ) -> Result<f64, RootFinderError>
Finds a root of f within the given bracket.