pub trait FindRootWithDerivative<F, D>{
// Required method
fn find_with_derivative(
&self,
f: F,
derivative: D,
initial_guess: f64,
) -> Result<f64, RootFinderError>;
}Expand description
Finds a root of f using both the function and its derivative.
Required Methods
Sourcefn find_with_derivative(
&self,
f: F,
derivative: D,
initial_guess: f64,
) -> Result<f64, RootFinderError>
fn find_with_derivative( &self, f: F, derivative: D, initial_guess: f64, ) -> Result<f64, RootFinderError>
Finds a root of f using derivative, starting from initial_guess.